multidim.models.CDER.get_params — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- All Modules, Classes, and Methods
- multidim.models.CDER

- index
- modules
- next
- previous

# multidim.models.CDER.get_params

`CDER.` `get_params`(deep=False)

  Pass original kwargs internally.

#### Previous topic

multidim.models.CDER.gausscoords

#### Next topic

multidim.models.CDER.plot

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.